@@ -10,12 +10,12 @@ expect_write2_worked <- function(FUN, object, reference, ...)
   skip_on_cran()
   FUN <- match.fun(FUN)
   filename <- tempfile()
-  on.exit(expect_true(file.remove(paste0(filename, ".Rmd"))))
+  # on.exit(expect_true(file.remove(paste0(filename, ".Rmd"))))
   if(!file.exists(reference)) skip("Couldn't find the reference file.")
   if(!file.create(paste0(filename, ".Rmd"))) skip("Couldn't create the temporary file.")
 
   expect_error(FUN(object, file = filename, ..., render. = TRUE, keep.rmd = TRUE, append. = FALSE, quiet = TRUE), NA)
-  on.exit(expect_true(file.remove(filename)), add = TRUE)
+  # on.exit(expect_true(file.remove(filename)), add = TRUE)
 
   generated <- readLines(paste0(filename, ".Rmd"))
   expect_output_file(cat(generated, sep = "\n"), reference)
